@@ -8,7 +8,7 @@ use 5.006;
 
 use Carp ();
 
-our $VERSION   = '0.10';
+our $VERSION   = '0.11';
 our $AUTHORITY = 'cpan:STEVAN';
 
 BEGIN {
@@ -115,13 +115,14 @@ UNIVERSAL::Object - A useful base class
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
     package Person;
     use strict;
     use warnings;
+    use UNIVERSAL::Object;
 
     our @ISA = ('UNIVERSAL::Object');
     our %HAS = (
@@ -151,20 +152,20 @@ version 0.10
     # ...
 
     my $ceo = Employee->new(
-        name  => 'Alice',
-        title => 'CEO',
+        name      => 'Alice',
+        job_title => 'CEO',
     );
 
     my $manager = Employee->new(
-        name    => 'Bob',
-        title   => 'Middle Manager',
-        manager => $ceo,
+        name      => 'Bob',
+        job_title => 'Middle Manager',
+        manager   => $ceo,
     );
 
     my $pawn = Employee->new(
-        name    => 'Joe',
-        title   => 'Line Worker',
-        manager => $manager,
+        name      => 'Joe',
+        job_title => 'Line Worker',
+        manager   => $manager,
     );
 
 =head1 DESCRIPTION
